#!/bin/sh
#
######################################################################
# Usage:
#      ImportAgentTEPD <version> <source dir> <agent> <installhome> 
# Result:
#      0   Successful
#      >0  Failed
####################################################################
export IMPORTVERSION=$1
export SOURCEDIR=$2
export AGENTNAME=$3
export CANDLEHOME=$4

# simple verification if the candlehome
if [ ! -d "${CANDLEHOME}" ] ; then 
	exit 2
fi

# log the execution
echo "ImportAgentTEPD started with $1 $2 $3 $4">>${CANDLEHOME}/logs/ImportAgentTEPD.log


# check version. We only support version 610 and higher.
if [ "${IMPORTVERSION}" -lt "610" ]; then
	echo "ERROR: import of version ${IMPORTVERSION} not supported">>${CANDLEHOME}/logs/ImportAgentTEPD.log
	exit 1
fi
echo "importing version ${IMPORTVERSION}">>${CANDLEHOME}/logs/ImportAgentTEPD.log


# check source
if [ ! -d "${SOURCEDIR}/TEPD/CNP" ]; then
	echo "ERROR: source directory ${SOURCEDIR}/TEPD/CNP not found" >>${CANDLEHOME}/logs/ImportAgentTEPD.log
	exit 2
fi 
echo "source directory ${SOURCEDIR}/TEPD/CNP found" >>${CANDLEHOME}/logs/ImportAgentTEPD.log

# check targets
if [ ! -d "${KFW_BIN_DIR}/../../cj" ]; then
	echo "ERROR: target directory ${KFW_BIN_DIR}/../../cj not found" >>${CANDLEHOME}/logs/ImportAgentTEPD.log
	exit 2
fi 
echo "target directory ${KFW_BIN_DIR}/../../cj found" >>${CANDLEHOME}/logs/ImportAgentTEPD.log

# backup the cnp.sh
echo "=========== cnp.sh content backup begin =============" >> ${KFW_BIN_DIR}/../../cj/bin/cnpsh.bak
cat ${KFW_BIN_DIR}/../../cj/bin/cnp.sh >> ${KFW_BIN_DIR}/../../cj/bin/cnpsh.bak
echo "=========== cnp.sh content backup end =============" >> ${KFW_BIN_DIR}/../../cj/bin/cnpsh.bak

# process each jar file
IFS=`echo`
for i in `ls ${SOURCEDIR}/TEPD/CNP/*.jar 2>/dev/null`
do
	JARNAME=`basename $i`
	export JARNAME
	echo  "${SOURCEDIR}/TEPD/CNP/${JARNAME} found."  >>${CANDLEHOME}/logs/ImportAgentTEPD.log
	cp ${SOURCEDIR}/TEPD/CNP/${JARNAME} ${KFW_BIN_DIR}/../../cj/lib/${JARNAME}

	# add jar files to the cnp.sh
	for j in `ls ${CANDLEHOME}/bin/cnp.sh 2>/dev/null;ls ${CANDLEHOME}/bin/cnp_*.sh 2>/dev/null;ls ${KFW_BIN_DIR}/../../cj/bin/cnp.sh 2>/dev/null;ls ${KFW_BIN_DIR}/../../cj/bin/cnp_*.sh 2>/dev/null`
	do
		cat $j |sed -e "s/\(export *CLASSPATH=.*$\)/\1:\$\{KCJ_LIB\}\/${JARNAME}/">$j.new
		mv -f $j.new $j
		chmod ugo+x $j
		echo  "${JARNAME} added to the CLASSPATH in $j" >>${CANDLEHOME}/logs/ImportAgentTEPD.log
	done
done

