#!/bin/sh
#
######################################################################
# Usage:
#      ImportAgentTEPS <version> <source dir> <agent> <installhome> 
# Result:
#      0   Successful
#      >0  Failed
####################################################################
cd ${KFW_BIN_DIR}
export KFW_HOME=${KFW_BIN_DIR}/..

export IMPORTVERSION=$1
export SOURCEDIR=$2
export AGENTNAME=$3
export CANDLEHOME=$4
HAVECNPS=Y
HAVECNB=Y
HAVEHELPSVR=Y

# simple verification if the candlehome
if [ ! -d "${CANDLEHOME}" ] ; then 
	exit 2
fi

# log the execution
echo "ImportAgentTEPS started with $1 $2 $3 $4">>${CANDLEHOME}/logs/ImportAgentTEPS.log

# check version. We only support version 610 and higher.
if [ "${IMPORTVERSION}" -lt "610" ]; then
	echo "ERROR: import of version ${IMPORTVERSION} not supported">>${CANDLEHOME}/logs/ImportAgentTEPS.log
	exit 1
fi
echo "importing of version is ${IMPORTVERSION}">>${CANDLEHOME}/logs/ImportAgentTEPS.log


# check sources
if [ ! -d "${SOURCEDIR}/TEPS" ]; then
	echo "source directory ${SOURCEDIR}/TEPS not found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
	HAVECNPS=N
else    
        echo "source directory ${SOURCEDIR}/TEPS found">>${CANDLEHOME}/logs/ImportAgentTEPS.log
fi 

if [ ! -d "${SOURCEDIR}/TEPS/CNB" ]; then
	echo "source directory ${SOURCEDIR}/TEPS/CNB not found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
	HAVECNB=N
else 
        echo "source directory ${SOURCEDIR}/TEPS/CNB found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
fi

if [ ! -d "${SOURCEDIR}/TEPS/HELPSVR" ]; then
	echo "source directory ${SOURCEDIR}/TEPS/HELPSVR not found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
	HAVEHELPSVR=N
else 
        echo "source directory ${SOURCEDIR}/TEPS/HELPSVR found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
fi

# need at least one source directory
if [ "${HAVECNB}" = "N" -a "${HAVECNPS}" = "N" -a "${HAVEHELPSVR}" = "N" ]; then
       	echo "ERROR: No source directories found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
        exit 2
fi

# check targets
if [ ! -d ${KFW_HOME} ]; then
	echo "ERROR: target directory ${KFW_HOME} not found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
	exit 2
fi 
echo "target directory ${KFW_HOME} found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log

if [ ! -d ${KFW_HOME}/../cw ]; then
	echo "ERROR: target directory ${CANDLEHOME}/../cw not found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
	exit  2
fi 
echo "target directory ${CANDLEHOME}/../cw found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log

# copy Eclipse Help files 
if [ "${HAVEHELPSVR}" = "Y" ]; then
        # get Eclipse help directory    
        cd ${CANDLEHOME}/registry
        # extract help subdirectory from file kfxxxxxx.ver, where xxxxxx = subdirectory   
        KFW_HELP_SUBD=`ls | grep -e '\.ver' | grep -e 'kf' | tr -d 'kf' | tr -d '\.ver'`
        cd ${KFW_BIN_DIR}
        if [ -f ${CANDLEHOME}/${KFW_HELP_SUBD}/kf/eclipse/links/kf.link ]; then
            . ${CANDLEHOME}/${KFW_HELP_SUBD}/kf/eclipse/links/kf.link
            export KFW_HELP_DIR=${path}/
        else
            export KFW_HELP_DIR=${CANDLEHOME}/${KFW_HELP_SUBD}/kf/
        fi
        if [ -d ${KFW_HELP_DIR} ]; then
                cp -r ${SOURCEDIR}/TEPS/HELPSVR/eclipse ${KFW_HELP_DIR}
	        if [ ! "$?" = "0" ]; then
		        echo "ERROR: file copy ${SOURCEDIR}/TEPS/HELPSVR/eclipse ${KFW_HELP_DIR} failed" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
		        exit 2
                fi
                echo "file copy ${SOURCEDIR}/TEPS/HELPSVR/eclipse ${KFW_HELP_DIR} done" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
        else
                echo "target directory for Eclipse Help, ${KFW_HELP_DIR}, not found" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
	fi
fi

# copy all files/directories
if [ "${HAVECNPS}" = "Y" ]; then
	# copy CNPS files
	# copy classes
	if [ -d ${SOURCEDIR}/TEPS/CNPS/classes ]; then
		cp -r ${SOURCEDIR}/TEPS/CNPS/classes ${KFW_HOME}/
	
		if [ ! "$?" = "0" ]; then
			echo "ERROR: file copy ${SOURCEDIR}/TEPS/CNPS/classes ${KFW_HOME}/ failed" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
			exit 2
		fi 
	fi 
	
	# copy classes
	for i in `ls ${SOURCEDIR}/TEPS/CNPS/CMSATR/ |grep -i "\.atr$"`
	do
		cp -f ${SOURCEDIR}/TEPS/CNPS/CMSATR/$i /tmp/$i
		cd /tmp           
                # replace dos2unix calls
                cat $i |tr -d '\r' > $i.unix
                mv $i.unix $i 
                
                cd ${KFW_BIN_DIR} 
		if [ -e ${KFW_HOME}/tables/ATTRLIB/`echo $i|tr 'A-Z' 'a-z'` ]; then
			cp -f /tmp/$i ${KFW_HOME}/tables/ATTRLIB/`echo $i|tr 'A-Z' 'a-z'`
			rm -f /tmp/$i
		else
			cp -f /tmp/$i ${KFW_HOME}/tables/ATTRLIB/`echo $i|tr 'A-Z' 'a-z'`
			rm -f /tmp/$i
         chmod u=`ls -ld ${SOURCEDIR}/TEPS/CNPS/CMSATR/$i|cut -n -b 2-4 -|tr 'S' 's'`,g=`ls -ld ${SOURCEDIR}/TEPS/CNPS/CMSATR/$i|cut -n -b 5-7 -|tr 'S' 's'`,o=`ls -ld ${SOURCEDIR}/TEPS/CNPS/CMSATR/$i|cut -n -b 8-10|tr 'S' 's'` ${KFW_HOME}/tables/ATTRLIB/`echo $i|tr 'A-Z' 'a-z'`
		fi
		if [ ! "$?" = "0" ]; then
			echo "ERROR: file copy ${SOURCEDIR}/TEPS/CNPS/CMSATR/$i ${KFW_HOME}/tables/ATTRLIB/ failed" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
			exit 2
		fi 
	done
	# copy sql files
	for i in `ls ${SOURCEDIR}/TEPS/CNPS/SQLLIB/ |grep -i "\.sql$"`
	do
		cp -f ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i /tmp/$i
		cd /tmp           
                # replace dos2unix calls
                cat $i |tr -d '\r' > $i.unix
                mv $i.unix $i 
                
                cd ${KFW_BIN_DIR} 
		if [ -e ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'` ]; then
			cp -f /tmp/$i ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'`
			rm -f /tmp/$i
		else
			cp -f /tmp/$i ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'`
			rm -f /tmp/$i
         chmod u=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 2-4 -|tr 'S' 's'`,g=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 5-7 -|tr 'S' 's'`,o=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 8-10|tr 'S' 's'` ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'`
		fi
		if [ ! "$?" = "0" ]; then
			echo "ERROR: file copy ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i ${KFW_HOME}/sqllib/ failed" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
			exit 2
		fi 
	done
	# copy parm files
	for i in `ls ${SOURCEDIR}/TEPS/CNPS/SQLLIB/ |grep -i "\.parms$"`
	do
		cp -f ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i /tmp/$i
		cd /tmp           
                # replace dos2unix calls
                cat $i |tr -d '\r' > $i.unix
                mv $i.unix $i 

                cd ${KFW_BIN_DIR} 
		if [ -e ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'` ]; then
			cp -f /tmp/$i ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'`
			rm -f /tmp/$i
		else
			cp -f /tmp/$i ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'`
			rm -f /tmp/$i
         chmod u=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 2-4 -|tr 'S' 's'`,g=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 5-7 -|tr 'S' 's'`,o=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 8-10|tr 'S' 's'` ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'`
		fi
		if [ ! "$?" = "0" ]; then
			echo "ERROR: file copy ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i ${KFW_HOME}/sqllib/ failed" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
			exit 2
		fi 
	done
	# copy xml files
	for i in `ls ${SOURCEDIR}/TEPS/CNPS/SQLLIB/ |grep -i "\.xml$"`
	do
		cp -f ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i /tmp/$i
		cd /tmp           
                # replace dos2unix calls
                cat $i |tr -d '\r' > $i.unix
                mv $i.unix $i 

                cd ${KFW_BIN_DIR}
		if [ -e ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'` ]; then
                        rm -f ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'` 
                fi
		if [ -e ${KFW_HOME}/sqllib/$i ]; then
			cp -f /tmp/$i ${KFW_HOME}/sqllib/$i
			rm -f /tmp/$i
		else
			cp -f /tmp/$i ${KFW_HOME}/sqllib/$i
			rm -f /tmp/$i
         chmod u=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 2-4 -|tr 'S' 's'`,g=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 5-7 -|tr 'S' 's'`,o=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 8-10|tr 'S' 's'` ${KFW_HOME}/sqllib/$i
		fi
		if [ ! "$?" = "0" ]; then
			echo "ERROR: file copy ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i ${KFW_HOME}/sqllib/ failed" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
			exit 2
		fi
	done
	# copy odi files
	for i in `ls ${SOURCEDIR}/TEPS/CNPS/ |grep -i "^doc"`
	do
		cp -f ${SOURCEDIR}/TEPS/CNPS/$i /tmp/$i
		cd /tmp           
                # replace dos2unix calls
                cat $i |tr -d '\r' > $i.unix
                mv $i.unix $i 

                cd ${KFW_BIN_DIR} 
		if [ -e ${KFW_HOME}/data/`echo $i|tr 'A-Z' 'a-z'` ]; then
			cp -f /tmp/$i ${KFW_HOME}/data/`echo $i|tr 'A-Z' 'a-z'`
			rm -f /tmp/$i
		else
			cp -f /tmp/$i ${KFW_HOME}/data/`echo $i|tr 'A-Z' 'a-z'`
			rm -f /tmp/$i
         chmod u=`ls -ld ${SOURCEDIR}/TEPS/CNPS/$i|cut -n -b 2-4 -|tr 'S' 's'`,g=`ls -ld ${SOURCEDIR}/TEPS/CNPS/$i|cut -n -b 5-7 -|tr 'S' 's'`,o=`ls -ld ${SOURCEDIR}/TEPS/CNPS/$i|cut -n -b 8-10|tr 'S' 's'` ${KFW_HOME}/data/`echo $i|tr 'A-Z' 'a-z'`
		fi	
		if [ ! "$?" = "0" ]; then
			echo "ERROR: file copy ${SOURCEDIR}/TEPS/CNPS/$i ${KFW_HOME}/data/ failed" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
			exit 2
		fi
	done
	
	# copy his files
	for i in `ls ${SOURCEDIR}/TEPS/CNPS/SQLLIB |grep -i "his$"`
	do
		cp -f ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i /tmp/$i
		cd /tmp           
                # replace dos2unix calls
                cat $i |tr -d '\r' > $i.unix
                mv $i.unix $i 

                cd ${KFW_BIN_DIR} 
		if [ -e ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'` ]; then
			cp -f /tmp/$i ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'`
			rm -f /tmp/$i
		else
			cp -f /tmp/$i ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'`
			rm -f /tmp/$i
         chmod u=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 2-4 -|tr 'S' 's'`,g=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 5-7 -|tr 'S' 's'`,o=`ls -ld ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i|cut -n -b 8-10|tr 'S' 's'` ${KFW_HOME}/sqllib/`echo $i|tr 'A-Z' 'a-z'`
		fi
		if [ ! "$?" = "0" ]; then
			echo "ERROR: file copy ${SOURCEDIR}/TEPS/CNPS/SQLLIB/$i ${KFW_HOME}/sqllib/ failed" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
			exit 2
		fi
	done
fi

if [ "${HAVECNB}" = "Y" ]; then
	# copy CNB files
	# copy classes files
	cp -r ${SOURCEDIR}/TEPS/CNB/classes ${KFW_HOME}/../cw/
	if [ ! "$?" = "0" ]; then
		echo "ERROR: file copy ${SOURCEDIR}/TEPS/CNB/classes ${KFW_HOME}/../cw/ failed" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
		exit 2
	fi
	cp ${SOURCEDIR}/TEPS/CNB/classes/*.inf ${KFW_HOME}/../cw/
	echo file copy ${SOURCEDIR}/TEPS done >>${CANDLEHOME}/logs/ImportAgentTEPS.log
			
	#   backup the applet.html file
	echo "=========== applet.html content backup begin =============" >> ${KFW_HOME}/../cw/applethtml.bak
	cat ${KFW_HOME}/../cw/applet.html >> ${KFW_HOME}/../cw/applethtml.bak
	echo "=========== applet.html content backup end =============" >> ${KFW_HOME}/../cw/applethtml.bak
	oldIFS=$IFS
	#   check the  inf file                 
	for f in `ls ${SOURCEDIR}/TEPS/CNB/classes/*.inf |tee /dev/null`
	do
		echo  "${f} found">>${CANDLEHOME}/logs/ImportAgentTEPS.log
		# process each jar file listed in it

		IFS=`echo`
                # replace dos2unix calls
		for i in `cat "${f}" |tr -d '\r'`
		do
			IFS=$oldIFS
                        echo 'echo $1'>/tmp/tmpscript1.sh
                        export JARNAME="`sh /tmp/tmpscript1.sh $i`"
                        rm -f /tmp/tmpscript1.sh
                        echo 'echo $2'>/tmp/tmpscript2.sh
                        export VERSIONTAG="`sh /tmp/tmpscript2.sh $i`"
                        rm -f /tmp/tmpscript2.sh
			
			# check existence of the jar file
			if [ ! -f "${SOURCEDIR}/TEPS/CNB/classes/${JARNAME}" ]; then
				echo  "ERROR: ${SOURCEDIR}/TEPS/CNB/classes/${JARNAME} can not be found." >>${CANDLEHOME}/logs/ImportAgentTEPS.log
				exit 2
			fi
			echo  "${SOURCEDIR}/TEPS/CNB/classes/${JARNAME} found."  >>${CANDLEHOME}/logs/ImportAgentTEPS.log

			# add jar files to the applet.html
			cat ${KFW_HOME}/../cw/applet.html |sed -e "s/\(< *PARAM  *NAME *= *CACHE_ARCHIVE  *VALUE *=.*[^,]\)\(,\{0,1\}\)\( *\">.*\)/\1, ${JARNAME},\3/">${KFW_HOME}/../cw/applet.html.new1
	
			echo  "${JARNAME} added to the CACHE_ARCHIVE">>${CANDLEHOME}/logs/ImportAgentTEPS.log
	
			# add version tag to the applet.html
			cat ${KFW_HOME}/../cw/applet.html.new1 |sed -e "s/\(< *PARAM  *NAME *= *CACHE_VERSION  *VALUE *=.*[^,]\)\(,\{0,1\}\)\( *\">.*\)/\1, ${VERSIONTAG},\3/">${KFW_HOME}/../cw/applet.html.new2
			mv -f ${KFW_HOME}/../cw/applet.html.new2 ${KFW_HOME}/../cw/applet.html
			rm -f ${KFW_HOME}/../cw/applet.html.new1
			echo  "${VERSIONTAG} added to the CACHE_VERSION" >>${CANDLEHOME}/logs/ImportAgentTEPS.log
		IFS=`echo`
		done
	done
fi
exit $?
