//
// Licensed Materials - Property of IBM
// 5724-C51
// (C) Copyright IBM Corp. 2007 All Rights Reserved.
//
// US Government Users Restricted Rights - Use, duplication or
// disclosure restricted by GSA ADP Schedule Contract with
// IBM Corp.

//Javascript functions needed in report wide namespace.  There is
//currently no support in the BIRT Designer Eclipse GUI for specifying
//that a report should use this file.  To use in a report, you
//have to edit the .rptdesign file by hand, and insert the following:
//    <list-property name="includeScripts">
//        <property>reportscripts.js</property>
//    </list-property>
//You can insert it after the <method> ... </method> near the beginning
//of the file.  You CAN refer to the methods in this file from scripts
//with the report.

//----------------------------------------------------------------------------
//This function takes a string values for time periods such as "L7"
//or "Y" and converts them to "Last Week" or "Yesterday"
function prettyTime (str)
{
	if(str == "T") // Today
	{
       return "Today";
	}
	else if(str == "Y") // Yesterday
	{
	   return "Yesterday";
	}
	else if(str == "L7") // Last 7 days
	{
	   return "Last 7 days";
	}
	else if(str == "L30") // Last 30 days
	{
	   return "Last 30 days";
	}
	else if(str == "L90") // Last 90 days
	{
	   return "Last 90 days";
	}
	else if(str == "CW") // Current week
	{
	   return "Current Week";
	}
	else if(str == "LW") // Last week
	{
	   return "Last Week";
	}
	else if(str == "CM") // Current month
	{
	   return "Current Month";
	}
	else if(str == "LM") // Last month
	{
	   return "Last Month";
	}
	else if(str == "L3M") // Last 3 months
	{
	    return "Last 3 Months";
	}
	else if(str == "YTD") // Current year
	{
	   return "Year to Date";
	}
	else return null;
}

//----------------------------------------------------------------------------
//This function takes a string values for for an optional parameter
//and returns the string *ALL* if it is not set. Otherwise it will 
//return the value passed to it.
function prettyFilter (str)
{
   if (str == "" || str == " ")
     return "*ALL*";
   else
     return str;
}


//--------------------------------------------------------------------
// Returns Date formed from given Candle Time string.  Candle Time
// is a string representation of time formatted as
// CCCMMddHHmmssSSS, where CCC is years since 1900 and other fields
// as defined in the Java SimpleDateFormat class.  For example,
// 1061206092057001 = 2006/12/06 09:20:57.001
function candleTimeToString(candleTime) {
  var s = (parseInt(1900) + parseInt(candleTime.substr(0,3)))  + "/" +
    candleTime.substr(3,2) + "/" +
    candleTime.substr(5,2) + " " +
    candleTime.substr(7,2) + ":" +
    candleTime.substr(9,2) + ":" +
    candleTime.substr(11,2);
  return s;
}



//--------------------------------------------------------------------
// Returns string containing ddd:hh:mm:ss of delta between two Candle
// time stamps. 
// Candle Time is a string representation of time formatted as
// CCCMMddHHmmssSSS, where CCC is years since 1900 and other fields
// as defined in the Java SimpleDateFormat class.  For example,
// 1061206092057001 = 2006/12/06 09:20:57.001
function candleDeltaTime(candleTime1,candleTime2) {
  var date1 = new Date(candleTimeToDate(candleTime1));
  var date2 = new Date(candleTImeToDate(candleTime2));
  var ddd = DateTimeSpan.days(date1,date2);
  var date3 = DateTimeSpan.subDate(date2,0,0,ddd);
  var hh = DateTimeSpan.hours(date1,date3);
  date3 = DateTimeSpan.subTime(date3,hh,00,00);
  var mm = DateTimeSpan.minutes(date1,date3);
  date3 = DateTimeSpan.subTime(date3,00,mm,00);
  var ss = DateTimeSpan.seconds(date1,date3);
  var result = "";
  if (ddd < 10) {
    result += "0";
  }
  if (ddd < 100) {
    result += "0";
  }
  result += ddd;
  result += ":";
  if (hh < 10) {
    result += "0";
  }
  result += hh;
  result += ":";
  if (mm < 10) {
    result += "0";
  }
  result += mm;
  result += ":";
  if (ss < 10) {
    result += "0";
  }
  result += ss;
  return result;
}

//--------------------------------------------------------------------
// Returns string containing ddd:hh:mm:ss of delta between two date/time
// values. 
function candleDeltaTime1(date1,date2) {
  var ddd = DateTimeSpan.days(date1,date2);
  var date3 = DateTimeSpan.subDate(date2,0,0,ddd);
  var hh = DateTimeSpan.hours(date1,date3);
  date3 = DateTimeSpan.subTime(date3,hh,00,00);
  var mm = DateTimeSpan.minutes(date1,date3);
  date3 = DateTimeSpan.subTime(date3,00,mm,00);
  var ss = DateTimeSpan.seconds(date1,date3);
  var result = "";
  if (ddd < 10) {
    result += "0";
  }
  if (ddd < 100) {
    result += "0";
  }
  result += ddd;
  result += ":";
  if (hh < 10) {
    result += "0";
  }
  result += hh;
  result += ":";
  if (mm < 10) {
    result += "0";
  }
  result += mm;
  result += ":";
  if (ss < 10) {
    result += "0";
  }
  result += ss;
  return result;
}




//--------------------------------------------------------------------
// Returns number of seconds between two Candle time stamps.
function candleDeltaTimeSec(candleTime1,candleTime2) {
  var date1 = new Date(candleTime1);
  var date2 = new Date(candleTime2);
  var ss = DateTimeSpan.seconds(date1,date2);
  return ss;
}

//--------------------------------------------------------------------
// Returns number of seconds between two Candle time stamps.
function DeltaTimeSec(Time1,Time2) {
  var ss = DateTimeSpan.seconds(Time1,Time2);
  return ss;
}

//--------------------------------------------------------------------
//This functoin takes a string and replaces all underscores with spaces
//an input of "Test_Input" would return "Test Input"
function convertIntoSp (str)
{
	while(str.indexOf("_") != -1)
	{
		str = str.replace("_", " ");
	}
	
	return str;
}

//--------------------------------------------------------------------
//This functoin takes a string containing an originnode and returns 
//the LPAR name from it.
function getLPAR (str)
{
    var result = getOriginnodeMiddle(str);
	return result;
}

//--------------------------------------------------------------------
//This function takes a string containing an originnode and returns 
//the first part (usually plex name). 
function getOriginnodeFirst (str)
{
    var result = "";
    var i = str.indexOf(":");
    if (i > 0) 
    {
       result += str.substr(0,i);
    }
    else
    {
       result += str;
    }
	return result;
}


//--------------------------------------------------------------------
//This function takes a string containing an originnode and returns 
//the middle portion (usually smfid).
function getOriginnodeMiddle (str)
{
    var result = "";
    var work = "";
    var i = str.indexOf(":");
    if (i > 0) 
    {
       work = str.substr(i+1);
       i = work.indexOf(":");
       if (i>0) 
       {  
         result += work.substr(0,i);
       }
    }
	return result;
}


//--------------------------------------------------------------------
//This function takes a string containing an originnode and returns 
//the last portion (usually type of node).
function getOriginnodeLast (str)
{
    var result = "";
    var work = "";
    var i = str.indexOf(":");
    if (i > 0) 
    {
       work = str.substr(i+1);
       i = work.indexOf(":");
       if (i > 0)
       {
            result += work.substr(i+1);
       }   
    }
	return result;
}
//driver class is obtained form datasource.getExtenstionProperty("odaDriverClass");
function modifyQueryBasedOnDBType(queryText,datasourceDriverClass)
{  
	 if(datasourceDriverClass.indexOf("oracle")>= 0 || datasourceDriverClass.indexOf("sqlserver")>= 0 || 	datasourceDriverClass.indexOf("mysql")>= 0)
  	 queryText = queryText.replaceAll("substr", "substring");
   return queryText;  	
	
}


